@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2003-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2003-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -711,7 +711,8 @@ class Ingo_Script_Sieve extends Ingo_Script_Base
                                   'comparator' => $comparator);
                     $use_address_test = false;
 
-                    if ($condition['match'] != 'regex') {
+                    if ($condition['match'] != 'regex' &&
+                        $condition['field'] != 'Body') {
                         $condition['value'] = preg_replace('/(.)(?<!\\\)\,(.)/',
                                                            "$1\n$2",
                                                            $condition['value']);
